==> series-1.0.1.tar.gz: series-1.0.1/series/__init__.py <==
__copyright__ = """ Copyright (c) 2011-2012 Torsten Schmits

This program is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, see <http://www.gnu.org/licenses/>.
"""

import os, re
from itertools import imap

from tek import debug, ConfigClient
from tek.tools import find_iter
from tek.config import lazy_configurable

import series.config
from series.errors import MissingMetadata

conf = ConfigClient('series')

def dir_info(dir):
    rex = conf('series_dir') + '(/([^/]+))?(/s(\d+))?(/.*)?'
    match = re.match(rex, dir)
    if match:
        return match.group(2), match.group(4)
    else:
        return None, None

styles = (r's?{}e{}', r'{}x{}', r's?{}.*e{}', r'(\d\d)(\d\d){}?{}?',
          r'(\d)(\d\d)', r'(){}{}?', r'{}.*?{}')
digits = (r'(\d\d?)', r'(\d\d?)')
regexes = [s.format(*digits) for s in styles]

def episode_enumeration_match(filename):
    searcher = lambda s: re.search(s, filename, re.I)
    rex = imap(searcher, regexes)
    return find_iter(lambda x: x, rex)

def episode_enumeration(filename):
    if isinstance(filename, basestring):
        match = episode_enumeration_match(filename)
        if match and all(s.isdigit() for s in match.groups()[:2]):
            return map(int, match.groups()[:2])
    return None, None

def episode_number(filename):
    return episode_enumeration(filename)[1]

def season_dir(series, season):
    return os.path.join(conf('series_dir'), series, 's{}'.format(season))

def get_release(series, season, number):
    filename = '.release_{}'.format(unicode(number).zfill(2))
    release_file = os.path.join(season_dir(series, season), filename)
    if not os.path.isfile(release_file):
        return None
    else:
        with open(release_file) as f:
            return f.readlines()[0].rstrip()

def latest_season_dir(series):
    series_dir = os.path.join(conf('series_dir'), series)
    is_series = lambda dir: re.match('s\d\d?', dir)
    latest = sorted(filter(is_series, os.listdir(series_dir)))[-1]
    return os.path.join(series_dir, latest)

def make_series_name(string):
    string = string.strip('-[_. ]+')
    parts = filter(None, re.split(r'[_. ]+', string))
    string = '_'.join(parts)
    return string.lower()

def episode_metadata(filename):
    result = episode_enumeration_match(filename)
    if result:
        groups = list(result.groups())
        index = result.start()
    series_name = make_series_name(filename[:index])
    season, number = groups[:2]
    return series_name, season, number

class EpisodeMetadata(list):
    def __init__(self, series, season, episode, release=None, extension=None):
        super(EpisodeMetadata, self).__init__([series, int(season),
                                               int(episode)])
        self.release = release
        self.extension = extension

    @property
    def series(self):
        return self[0]

    @property
    def season(self):
        return self[1]

    @property
    def season_zfill(self):
        return unicode(self.season).zfill(2)

    @property
    def episode(self):
        return self[2]

    @property
    def episode_zfill(self):
        return unicode(self.episode).zfill(2)

    @property
    def all(self):
        return self + [self.release]

    @property
    def filename(self):
        file = '{0}_{1}x{2}.{3}'
        if self.extension is None:
            raise MissingMetadata('No extension in EpisodeMetadata!')
        return file.format(self.series, self.season_zfill, self.episode_zfill,
                           self.extension)

    @property
    def local_path(self):
        path = os.path.join(self.series, 's{}'.format(self.season))
        if self.extension == 'srt':
            path = os.path.join(path, 'sub')
        return os.path.join(path, self.filename)

    @property
    def is_subtitle(self):
        return self.extension == 'srt'

class SubtitleMetadata(EpisodeMetadata):
    def __init__(self, series, season, episode, release=None, extension='srt'):
        super(SubtitleMetadata, self).__init__(series, season, episode,
                                               release=release,
                                               extension=extension)

    @property
    def is_subtitle(self):
        return True

@lazy_configurable(series=['series_dir'])
class EpisodeMetadataFactory(object):
    def from_filename(self, path):
        path = os.path.basename(path)
        series_name, season, number = episode_metadata(path)
        release = get_release(series_name, season, number)
        extension = path.rsplit('.', 1)[-1]
        typ = SubtitleMetadata if extension == 'srt' else EpisodeMetadata
        return typ(series_name, season, number, release, extension)

==> series-1.1.1.tar.gz: series-1.1.1/series/__init__.py <==
import os
import re
import mimetypes


from tek import ConfigClient
from tek.tools import find_iter
from tek.config import lazy_configurable

import series.config
from series.errors import MissingMetadata

conf = ConfigClient('series')


def dir_info(dir):
    rex = conf('series_dir') + '(/([^/]+))?(/s(\d+))?(/.*)?'
    match = re.match(rex, dir)
    if match:
        return match.group(2), match.group(4)
    else:
        return None, None

styles = (r's?{}e{}', r'{}x{}', r's?{}.*e{}', r'(\d\d)(\d\d){}?{}?',
          r'(\d)(\d\d)', r'(){}{}?', r'{}.*?{}')
digits = (r'(\d\d?)', r'(\d\d?)')
regexes = [s.format(*digits) for s in styles]


def episode_enumeration_match(filename):
    searcher = lambda s: re.search(s, filename, re.I)
    rex = map(searcher, regexes)
    return find_iter(lambda x: x, rex)


def episode_enumeration(filename):
    if isinstance(filename, str):
        match = episode_enumeration_match(filename)
        if match and all(s.isdigit() for s in match.groups()[:2]):
            return list(map(int, match.groups()[:2]))
    return None, None


def episode_number(filename):
    return episode_enumeration(filename)[1]


def season_dir(series, season):
    return os.path.join(conf('series_dir'), series, 's{}'.format(season))


def get_release(series, season, number):
    filename = '.release_{}'.format(str(number).zfill(2))
    release_file = os.path.join(season_dir(series, season), filename)
    if not os.path.isfile(release_file):
        return None
    else:
        with open(release_file) as f:
            return f.readlines()[0].rstrip()


def latest_season_dir(series):
    series_dir = os.path.join(conf('series_dir'), series)
    is_series = lambda dir: re.match('s\d\d?', dir)
    latest = sorted(filter(is_series, os.listdir(series_dir)))[-1]
    return os.path.join(series_dir, latest)


def make_series_name(string):
    string = string.strip('-[_. ]+')
    parts = [_f for _f in re.split(r'[_. ]+', string) if _f]
    string = '_'.join(parts)
    return string.lower()


def episode_metadata(filename):
    result = episode_enumeration_match(filename)
    if result:
        groups = list(result.groups())
        index = result.start()
        series_name = make_series_name(filename[:index])
        season, number = groups[:2]
        return series_name, season, number


def is_video(_file):
    guess = mimetypes.guess_type(_file)
    return (bool(guess) and isinstance(guess[0], str) and
            guess[0].split('/')[0] == 'video')


def is_episode(_file):
    return isinstance(episode_enumeration(_file)[0], int)


class EpisodeMetadata(list):

    def __init__(self, series, season, episode, release=None, extension=None):
        super(EpisodeMetadata, self).__init__([series, int(season),
                                               int(episode)])
        self.release = release
        self.extension = extension

    @property
    def series(self):
        return self[0]

    @property
    def season(self):
        return self[1]

    @property
    def season_zfill(self):
        return str(self.season).zfill(2)

    @property
    def episode(self):
        return self[2]

    @property
    def episode_zfill(self):
        return str(self.episode).zfill(2)

    @property
    def all(self):
        return self + [self.release]

    @property
    def filename(self):
        file = '{0}_{1}x{2}.{3}'
        if self.extension is None:
            raise MissingMetadata('No extension in EpisodeMetadata!')
        return file.format(self.series, self.season_zfill, self.episode_zfill,
                           self.extension)

    @property
    def local_path(self):
        path = os.path.join(self.series, 's{}'.format(self.season))
        if self.extension == 'srt':
            path = os.path.join(path, 'sub')
        return os.path.join(path, self.filename)

    @property
    def is_subtitle(self):
        return self.extension == 'srt'


class SubtitleMetadata(EpisodeMetadata):
    def __init__(self, series, season, episode, release=None, extension='srt'):
        super(SubtitleMetadata, self).__init__(series, season, episode,
                                               release=release,
                                               extension=extension)

    @property
    def is_subtitle(self):
        return True


@lazy_configurable(series=['series_dir'])
class EpisodeMetadataFactory(object):

    def from_filename(self, path):
        path = os.path.basename(path)
        series_name, season, number = episode_metadata(path)
        release = get_release(series_name, season, number)
        extension = path.rsplit('.', 1)[-1]
        typ = SubtitleMetadata if extension == 'srt' else EpisodeMetadata
        return typ(series_name, season, number, release, extension)
